@@ -96,7 +96,7 @@ void MainWindow::refresh()
 }
 
 // replace default Debian repos
-void MainWindow::replaceDebianRepos(const QString &url)
+void MainWindow::replaceDebianRepos(QString url)
 {
     QStringList files;
     QString cmd;
@@ -114,15 +114,15 @@ void MainWindow::replaceDebianRepos(const QString &url)
 
         // backup file
         cmd = "cp " + file + " /etc/apt/sources.list.d/backups/" + fileinfo.fileName() + ".$(date +%s)";
-        system(cmd.toUtf8());
+        shell->run(cmd);
 
-        cmd = "sed -i 's;deb\\s.*/debian/;deb " + url + ";' " + file ; // replace deb lines in file
-        system(cmd.toUtf8());
-        cmd = "sed -i 's;deb-src\\s.*/debian/;deb-src " + url + ";' " + file; // replace deb-src lines in file
-        system(cmd.toUtf8());
+        cmd = "sed -i 's;deb\\s.*/debian/*[^-];deb " + url + " ;' " + file ; // replace deb lines in file
+        shell->run(cmd);
+        cmd = "sed -i 's;deb-src\\s.*/debian/*[^-];deb-src " + url + ";' " + file; // replace deb-src lines in file
+        shell->run(cmd);
         if (url == "https://deb.debian.org/debian/") {
             cmd = "sed -i 's;deb\\s*http://security.debian.org/;deb https://deb.debian.org/debian-security/;' " + file; // replace security.debian.org in file
-            system(cmd.toUtf8());
+            shell->run(cmd);
         }
     }
     QMessageBox::information(this, tr("Success"),
@@ -268,7 +268,7 @@ void MainWindow::cancelOperation()
 void MainWindow::displaySelected(const QString &repo)
 {
     for (int row = 0; row < ui->listWidget->count(); ++row) {
-        QRadioButton *item = (QRadioButton*)ui->listWidget->itemWidget(ui->listWidget->item(row));
+        QRadioButton *item = static_cast<QRadioButton*>(ui->listWidget->itemWidget(ui->listWidget->item(row)));
         if (item->text().contains(repo)) {
             item->setChecked(true);
             ui->listWidget->scrollToItem(ui->listWidget->item(row));
@@ -291,7 +291,7 @@ void MainWindow::setSelected()
 {
     QString url;
     for (int row = 0; row < ui->listWidget->count(); ++row) {
-        QRadioButton *item = (QRadioButton*)ui->listWidget->itemWidget(ui->listWidget->item(row));
+        QRadioButton *item = static_cast<QRadioButton*>(ui->listWidget->itemWidget(ui->listWidget->item(row)));
         if (item->isChecked()) {
             url = item->text().section(" - ", 1, 1).trimmed();
             replaceRepos(url);
@@ -368,7 +368,7 @@ QFileInfoList MainWindow::listAptFiles()
     QDir apt_dir("/etc/apt/sources.list.d");
     list << apt_dir.entryInfoList(QStringList("*.list"));
     QFile file("/etc/apt/sources.list");
-    if (file.size() != 0) {
+    if (file.size() != 0 && shell->run("grep '^#*[ ]*deb' " + file.fileName(), true)) {
         list << file;
     }
     return list;
